@@ -5,11 +5,11 @@ import (
 	"log"
 	"os"
 
-	"github.com/99designs/aws-vault/v7/prompt"
-	"github.com/99designs/aws-vault/v7/vault"
-	"github.com/99designs/keyring"
+	"github.com/byteness/keyring"
 	"github.com/alecthomas/kingpin/v2"
 	"github.com/aws/aws-sdk-go-v2/aws"
+	"github.com/byteness/aws-vault/v7/prompt"
+	"github.com/byteness/aws-vault/v7/vault"
 )
 
 type AddCommandInput struct {
