@@ -8,11 +8,11 @@ import (
 	"os"
 	"time"
 
-	"github.com/99designs/aws-vault/v7/iso8601"
-	"github.com/99designs/aws-vault/v7/vault"
-	"github.com/99designs/keyring"
 	"github.com/alecthomas/kingpin/v2"
 	"github.com/aws/aws-sdk-go-v2/aws"
+	"github.com/byteness/aws-vault/v7/iso8601"
+	"github.com/byteness/aws-vault/v7/vault"
+	"github.com/byteness/keyring"
 	ini "gopkg.in/ini.v1"
 )
 
@@ -60,7 +60,7 @@ func ConfigureExportCommand(app *kingpin.Application, a *AwsVault) {
 		BoolVar(&input.UseStdout)
 
 	cmd.Arg("profile", "Name of the profile").
-		Required().
+		//Required().
 		HintAction(a.MustGetProfileNames).
 		StringVar(&input.ProfileName)
 
@@ -79,6 +79,17 @@ func ConfigureExportCommand(app *kingpin.Application, a *AwsVault) {
 			return err
 		}
 
+		if input.ProfileName == "" {
+			// If no profile provided select from configured AWS profiles
+			ProfileName, err := pickAwsProfile(f.ProfileNames())
+
+			if err != nil {
+				return fmt.Errorf("unable to select a 'profile'. Try --help: %w", err)
+			}
+
+			input.ProfileName = ProfileName
+		}
+
 		err = ExportCommand(input, f, keyring)
 		app.FatalIfError(err, "exec")
 		return nil
