@@ -6,11 +6,11 @@ import (
 	"log"
 	"time"
 
-	"github.com/99designs/aws-vault/v7/vault"
-	"github.com/99designs/keyring"
 	"github.com/alecthomas/kingpin/v2"
 	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/service/iam"
+	"github.com/byteness/aws-vault/v7/vault"
+	"github.com/byteness/keyring"
 )
 
 type RotateCommandInput struct {
@@ -29,19 +29,31 @@ func ConfigureRotateCommand(app *kingpin.Application, a *AwsVault) {
 		BoolVar(&input.NoSession)
 
 	cmd.Arg("profile", "Name of the profile").
-		Required().
+		//Required().
 		HintAction(a.MustGetProfileNames).
 		StringVar(&input.ProfileName)
 
 	cmd.Action(func(c *kingpin.ParseContext) (err error) {
 		input.Config.MfaPromptMethod = a.PromptDriver(false)
+
+		f, err := a.AwsConfigFile()
+		if err != nil {
+			return err
+		}
 		keyring, err := a.Keyring()
 		if err != nil {
 			return err
 		}
-		f, err := a.AwsConfigFile()
-		if err != nil {
-			return err
+
+		if input.ProfileName == "" {
+			// If no profile provided select from configured AWS profiles
+			ProfileName, err := pickAwsProfile(f.ProfileNames())
+
+			if err != nil {
+				return fmt.Errorf("unable to select a 'profile'. Try --help: %w", err)
+			}
+
+			input.ProfileName = ProfileName
 		}
 
 		err = RotateCommand(input, f, keyring)
