@@ -9,8 +9,8 @@ import (
 	"net/http"
 	"time"
 
-	"github.com/99designs/aws-vault/v7/iso8601"
 	"github.com/aws/aws-sdk-go-v2/aws"
+	"github.com/byteness/aws-vault/v7/iso8601"
 )
 
 const ec2CredentialsServerAddr = "127.0.0.1:9099"
@@ -47,8 +47,8 @@ func startEc2CredentialsServer(credsProvider aws.CredentialsProvider, region str
 	})
 
 	// used by AWS SDK to determine region
-	router.HandleFunc("/latest/meta-data/dynamic/instance-identity/document", func(w http.ResponseWriter, r *http.Request) {
-		fmt.Fprintf(w, `{"region": "`+region+`"}`)
+	router.HandleFunc("/latest/dynamic/instance-identity/document", func(w http.ResponseWriter, r *http.Request) {
+		fmt.Fprintf(w, `{"region": "%s"}`, region)
 	})
 
 	router.HandleFunc("/latest/meta-data/iam/security-credentials/local-credentials", credsHandler(credsProvider))
@@ -74,7 +74,7 @@ func withSecurityChecks(next *http.ServeMux) http.HandlerFunc {
 
 		// Check that the request is to 169.254.169.254
 		// Without this it's possible for an attacker to mount a DNS rebinding attack
-		// See https://github.com/99designs/aws-vault/issues/578
+		// See https://github.com/byteness/aws-vault/issues/578
 		if r.Host != ec2MetadataEndpointIP && r.Host != ec2MetadataEndpointAddr {
 			http.Error(w, fmt.Sprintf("Access denied for host '%s'", r.Host), http.StatusUnauthorized)
 			return
